@@ -33,7 +33,6 @@
 # /usr/share/common-licenses/AGPL-3; if not, see
 # <https://www.gnu.org/licenses/>.
 
-from __future__ import print_function
 
 import os
 import sys
@@ -47,7 +46,6 @@ from samba.dcerpc import misc
 from samba.ndr import ndr_unpack
 from samba.param import LoadParm
 from samba.samdb import SamDB
-from six.moves import input
 
 import univention.admin.config
 import univention.admin.modules
